Regular Expressions
::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   regularexpressions.rst
   charactermatching.rst
   extractingdata.rst
   combiningsearchingandextracting.rst
   escapecharacter.rst
   summary.rst
   bonussection.rst
   debugging.rst
   glossary.rst
   Exercises.rst
   hp-practice.rst
   mixedupcode.rst
   writecode.rst
   regex-group.rst
   regex-group-adv.rst
